@@ -893,16 +893,6 @@ Connect <- R6::R6Class(
       self$GET(path = path)
     },
 
-    #' @description Get R installations.
-    server_settings_r = function() {
-      lifecycle::deprecate_soft(
-        "0.3.1",
-        "Connect$server_settings_r()",
-        "get_runtimes()"
-      )
-      self$GET(v1_url("server_settings", "r"))
-    },
-
     #' @description Get server settings.
     server_settings = function() {
       self$GET(unversioned_url("server_settings"))
