@@ -229,121 +229,3 @@ set_thumbnail <- function(content, path) {
   # return the input (in case it inherits more than just Content)
   invisible(content)
 }
-
-
-#' Get the Content Image
-#'
-#' @description
-#'
-#' `r lifecycle::badge('deprecated')`
-#'
-#' Please use [`get_thumbnail`],
-#' [`delete_thumbnail`], and [`has_thumbnail`] instead.
-#'
-#' `get_image` saves the content image to the given path (default: temp file).
-#' `delete_image` removes the image (optionally saving to the given path)
-#' `has_image` returns whether the content has an image
-#'
-#' @param content A content object
-#' @param path optional. The path to the image on disk
-#'
-#' @rdname get_image
-#' @family content functions
-#' @export
-get_image <- function(content, path = NULL) {
-  lifecycle::deprecate_warn("0.3.1", "get_image()", "get_thumbnail()")
-
-  get_thumbnail(content, path)
-}
-
-#' @rdname get_image
-#' @export
-delete_image <- function(content, path = NULL) {
-  lifecycle::deprecate_warn("0.3.1", "delete_image()", "delete_thumbnail()")
-
-  if (!is.null(path)) {
-    get_thumbnail(content, path)
-  }
-
-  delete_thumbnail(content)
-}
-
-#' @rdname get_image
-#' @export
-has_image <- function(content) {
-  lifecycle::deprecate_warn("0.3.1", "has_image()", "has_thumbnail()")
-  has_thumbnail(content)
-}
-
-
-#' Set the Content Image
-#'
-#' @description
-#'
-#' `r lifecycle::badge('deprecated')`
-#'
-#' Please use [`set_thumbnail`] instead.
-#'
-#' Set the Content Image using a variety of methods.
-#'
-#' @details NOTE: `set_image_webshot()` requires [webshot2::webshot()], but currently
-#' skips and warns for any content that requires authentication until the
-#' `webshot2` package supports authentication.
-#'
-#' @param content A content object
-#' @param path The path to an image on disk
-#' @param url The url for an image
-#' @param ... Additional arguments passed on to [webshot2::webshot()]
-#'
-#' @rdname set_image
-#' @family content functions
-#' @export
-set_image_path <- function(content, path) {
-  lifecycle::deprecate_warn("0.3.1", "set_image_path()", "set_thumbnail()")
-  set_thumbnail(content, path)
-}
-
-
-#' @rdname set_image
-#' @export
-set_image_url <- function(content, url) {
-  lifecycle::deprecate_warn("0.3.1", "set_image_url()", "set_thumbnail()")
-  set_thumbnail(content, url)
-}
-
-
-#' @rdname set_image
-#' @export
-set_image_webshot <- function(content, ...) {
-  lifecycle::deprecate_warn("0.3.1", "set_image_webshot()", "set_thumbnail()")
-  validate_R6_class(content, "Content")
-  imgfile <- fs::file_temp(pattern = "webshot", ext = ".png")
-
-  rlang::check_installed("webshot2", "to take screenshots of applications")
-  content_details <- content$get_content_remote()
-
-  # check if it is possible to take the webshot
-  if (content_details$access_type != "all") {
-    warning(glue::glue(
-      "WARNING: unable to take webshot for content ",
-      "'{content_details$guid}' because authentication is not possible yet. ",
-      "Set access_type='all' to proceed."
-    ))
-    return(content)
-  }
-
-  # default args
-  args <- rlang::list2(...)
-
-  if (!"cliprect" %in% names(args)) {
-    args["cliprect"] <- "viewport"
-  }
-
-  rlang::inject(webshot2::webshot(
-    url = content_details$content_url,
-    file = imgfile,
-    !!!args
-  ))
-
-  set_thumbnail(content = content, path = imgfile)
-}
